@@ -7,12 +7,7 @@
  */
 
 
-#ifdef WIN32
-#include "win32config.h"
-#else
-#include "config.h"
-#endif
-#include <stdio.h>
+#include "libxml.h"
 #include <stdlib.h>
 #include <string.h>
 #include <libxml/xmlmemory.h>
@@ -890,7 +885,7 @@ attribute(void *ctx, const xmlChar *fullname, const xmlChar *value)
 	    ctxt->valid &= xmlValidateOneAttribute(&ctxt->vctxt, ctxt->myDoc,
 					       ctxt->node, ret, value);
 	}
-    } else {
+    } else if (ctxt->external != 2){
         /*
 	 * when validating, the ID registration is done at the attribute
 	 * validation level. Otherwise we have to do specific handling here.
