@@ -17,11 +17,13 @@ extern "C" {
  * use those to be sure nothing nasty will happen if
  * your library and includes mismatch
  */
+#ifndef LIBXML2_COMPILING_MSCCDEF
 extern void xmlCheckVersion(int version);
-#define LIBXML_DOTTED_VERSION "2.3.6"
-#define LIBXML_VERSION 20306
-#define LIBXML_VERSION_STRING "20306"
-#define LIBXML_TEST_VERSION xmlCheckVersion(20306);
+#endif /* LIBXML2_COMPILING_MSCCDEF */
+#define LIBXML_DOTTED_VERSION "2.3.7"
+#define LIBXML_VERSION 20307
+#define LIBXML_VERSION_STRING "20307"
+#define LIBXML_TEST_VERSION xmlCheckVersion(20307);
 
 /*
  * Whether the trio support need to be configured in
@@ -131,7 +133,9 @@ extern void xmlCheckVersion(int version);
 #endif
 
 #ifdef __GNUC__
+#ifdef HAVE_ANSIDECL_H
 #include <ansidecl.h>
+#endif
 #ifndef ATTRIBUTE_UNUSED
 #define ATTRIBUTE_UNUSED
 #endif
